@@ -3,8 +3,7 @@ from django.conf import settings
 
 import sys
 
-import proxy
-
+from django_react_toolkit import proxy
 
 class Command(BaseCommand):
     def add_arguments(self, parser) -> None:
